pub(crate) const TOPIC: &str = "rebels-b2b";
pub const DEFAULT_NETWORK_PORT: u16 = 37202;
pub(crate) const DEFAULT_SEED_PORT: u16 = 37201;
pub(crate) const DEFAULT_SEED_URL: &str = "frittura.org";
pub(crate) const DEFAULT_SEED_IPV6: &str = "2a01:239:22f:7e00::1";
